@@ -15,7 +15,7 @@ NULL
 #'
 #' It does not re-calculate tick marks, but lets \code{scale_x_*} and \code{scale_y_*}
 #' calculate and draw ticks and labels, and then modifies the ticks with brackets.
-#' 
+#'
 #' Both \code{length} and \code{tick.length} accepts a numeric scalar instead of
 #' a \code{\link[grid]{unit}} object that is interpreted as an \code{"npc"} unit.
 #'
@@ -52,32 +52,30 @@ brackets_horizontal <- function(direction = c('up','down'),
 
   if (!grid::is.unit(length))
     length <- unit(as.numeric(length), 'npc')
-  
+
   if (!is.waive(tick.length) && !grid::is.unit(tick.length))
     tick.length <- unit(as.numeric(tick.length), 'npc')
-  
+
   direction=match.arg(direction)
 
   # Returns a function
-  
-  #fn <- function(scale_details, axis, scale, position, theme) {
   fn <- function(guides, position, theme) {
-    agrob <-  panel_guides_grob(guides, position, theme)
-    
+    guide <- guide_for_position(guides, position)
+    agrob <- guide_gengrob(guide, theme)
     if (agrob$name == 'NULL') return(agrob)
 
     ind <- names(agrob$children) == 'axis'
     ind.notline <-  which(ind)
     ind.ticks <- which(grepl('polyline', sapply(agrob$children[[ind.notline]]$grobs, `[[`, i = 'name')))
-    ind.text <- which(grepl('titleGrob', sapply(agrob$children[[ind.notline]]$grobs, `[[`, i = 'name')))
+    ind.text <- which(grepl('title', sapply(agrob$children[[ind.notline]]$grobs, `[[`, i = 'name')))
     ticksgrob <- agrob$children[[ind.notline]]$grobs[[ind.ticks]]
-    
+
     # If theme(axis.ticks[.x/.y] = element_blank()), then ticksgrob is a
     # zeroGrob and we cannot change the ticks (polylineGrob), as $gp is NULL.
     if (!is.zero(ticksgrob) && !is.null(ticksgrob$gp)) {
       gp <- do.call(grid::gpar, ticksgrob$gp)
       nticks <- length(ticksgrob$id.lengths)
-  
+
       x <- rep(ticksgrob$x, each = 2) +
         rep(unit.c(length * -1, length * -1, length, length ), times = nticks)
       tick.length <- tick.length %|W|% theme$axis.ticks.length
@@ -87,13 +85,13 @@ brackets_horizontal <- function(direction = c('up','down'),
       id.lengths <- rep(4, times = nticks)
       brackets <- polylineGrob(x = x, y = y, id.lengths = id.lengths, gp = gp)
       labels <- agrob$children[[ind.notline]]$grobs[[ind.text]]
-      
+
     } else {
       labels <- agrob$children[[ind.notline]]$grobs[[ind.text]]
       tick.length <- unit(0, 'npc')
       brackets <- zeroGrob()
     }
-      
+
 
     gt <- switch(position,
       top = gtable::gtable_col('axis',
@@ -126,46 +124,41 @@ brackets_horizontal <- function(direction = c('up','down'),
 ## Turns out, there is no British spelling horizontal with an s...
 #' @export
 #' @keywords internal
-# @inheritParams brackets_horizontal
+#' @inheritParams brackets_horizontal
 brackets_horisontal <- brackets_horizontal
 
-
 #' @export
 #' @rdname brackets
-# @inheritParams brackets_horizontal
-#' @param direction Which way should the opening side of the brackets point?
-#'   up, down, left, or right?
-#' @param length Length of the unit, parallel with axis line.
-#' @param tick.length Height (width) of x-axis (y-axis) bracket.
-#'   If \code{waiver()} (default), use \code{axis.ticks.length} from \code{\link{theme}}.
+#  @inheritParams brackets_horizontal
 brackets_vertical <- function(direction = c('left','right'),
                               length = unit(0.05, 'npc'),
                               tick.length = waiver()) {
-  
+
   if (!grid::is.unit(length))
     length <- unit(as.numeric(length), 'npc')
-  
+
   if (!is.waive(tick.length) && !grid::is.unit(tick.length))
     tick.length <- unit(as.numeric(tick.length), 'npc')
-  
+
   direction=match.arg(direction)
   fn <- function(guides, position, theme) {
-    agrob <-  panel_guides_grob(guides, position, theme)
+    guide <- guide_for_position(guides, position)
+    agrob <- guide_gengrob(guide, theme)
     if (agrob$name == 'NULL') return(agrob)
 
     ind <- names(agrob$children) == 'axis'
     ind.notline <-  which(ind)
     ind.ticks <- which(grepl('polyline', sapply(agrob$children[[ind.notline]]$grobs, `[[`, i = 'name')))
-    ind.text <- which(grepl('titleGrob', sapply(agrob$children[[ind.notline]]$grobs, `[[`, i = 'name')))
+    ind.text <- which(grepl('title', sapply(agrob$children[[ind.notline]]$grobs, `[[`, i = 'name')))
     ticksgrob <- agrob$children[[ind.notline]]$grobs[[ind.ticks]]
 
-    
+
     # If theme(axis.ticks[.x/.y] = element_blank()), then ticksgrob is a
     # zeroGrob and we cannot change the ticks (polylineGrob), as $gp is NULL.
     if (!is.zero(ticksgrob) && !is.null(ticksgrob$gp)) {
       gp <- do.call(grid::gpar, ticksgrob$gp)
       nticks <- length(ticksgrob$id.lengths)
-  
+
       y <- rep(ticksgrob$y, each = 2) +
         rep(unit.c(length * -1, length * -1, length, length ), times = nticks)
       tick.length <- tick.length %|W|% theme$axis.ticks.length
@@ -180,7 +173,7 @@ brackets_vertical <- function(direction = c('left','right'),
       tick.length <- unit(0, 'npc')
       brackets <- zeroGrob()
     }
-    
+
     gt <- switch(position,
       left = gtable::gtable_row('axis',
         grobs = list(labels, brackets),
