@@ -38,11 +38,27 @@ is.waive <- function(x) inherits(x, "waiver")
 #' @keywords internal
 #' @rdname ggplot2-non-exports
 #' @name if-not-null
-#' @export 
+#' @export
 "%||%" <- function(a, b) {
   if (!is.null(a)) a else b
 }
 
+# From ggplot2/R/coord-.r
+# Renders an axis with the correct orientation or zeroGrob if no axis should be
+# generated
+# render_axis <- function(panel_params, axis, scale, position, theme) {
+#   browser()
+#   if (axis == "primary") {
+#     guide_axis(panel_params[[paste0(scale, ".major")]], panel_params[[paste0(scale, ".labels")]], position, theme)
+#   } else if (axis == "secondary" && !is.null(panel_params[[paste0(scale, ".sec.major")]])) {
+#     guide_axis(panel_params[[paste0(scale, ".sec.major")]], panel_params[[paste0(scale, ".sec.labels")]], position, theme)
+#   } else {
+#     zeroGrob()
+#   }
+# }
+
+
+#  From ggplot2/R/utilities-grid.r
 #' @import grid
 ggname <- function (prefix, grob) {
   grob$name <- grid::grobName(grob, prefix)
@@ -53,6 +69,30 @@ is.zero <- function (x)  {
   is.null(x) || inherits(x, "zeroGrob")
 }
 
+# From ggplot2/R/coord-cartesian-.r
+panel_guide_label <- function(guides, position, default_label) {
+  guide <- guide_for_position(guides, position) %||% guide_none(title = waiver())
+  guide$title %|W|% default_label
+}
+
+panel_guides_grob <- function(guides, position, theme) {
+  guide <- guide_for_position(guides, position) %||% guide_none()
+  guide_gengrob(guide, theme)
+}
+
+guide_for_position <- function(guides, position) {
+  has_position <- vapply(
+    guides,
+    function(guide) identical(guide$position, position),
+    logical(1)
+  )
+
+  guides <- guides[has_position]
+  guides_order <- vapply(guides, function(guide) as.numeric(guide$order)[1], numeric(1))
+  Reduce(guide_merge, guides[order(guides_order)])
+}
+
+
 # From ggplot2/R/grob-absolute.r
 absoluteGrob <- function(grob, width = NULL, height = NULL,
                          xmin = NULL, ymin = NULL, vp = NULL) {
@@ -99,16 +139,3 @@ plot_theme <- function (x, default = theme_get()) {
   }
 }
 is_theme_complete <- function(x) isTRUE(attr(x, "complete"))
-
-# From ggplot2/R/scale-.r
-# In place modification of a scale to change the primary axis
-scale_flip_position <- function(scale) {
-  scale$position <- switch(scale$position,
-    top = "bottom",
-    bottom = "top",
-    left = "right",
-    right = "left",
-    scale$position
-  )
-  invisible()
-}
